************************************************************************
* Program Name: KEG Dialog Template               Creation: 01/31/2002 *
*                                                                      *
*
* SAP Name    : ZESU_DIALOG_TEMPLATE              Application: BC      *
*                                                                      *
* Author      : Thomas Jung                       Type: 1              *
*______________________________________________________________________*
* Description :                                                        *
* Template program for dialog programming
*______________________________________________________________________*
* Inputs: N/A                                                          *
*                                                                      *
* Outputs: N/A
*
*______________________________________________________________________*
* External Routines                                                    *
*
*______________________________________________________________________*
* Return Codes: N/A                                                    *
*                                                                      *
*______________________________________________________________________*
* Ammendments:                                                         *
*    Programmer        Date     Req. #            Action               *
* ================  ==========  ======  ===============================*
*                                                                      *
************************************************************************

report  zesu_dialog_template message-id zes_general.

*----------------------------------------------------------------------*
* INCLUDE                                                              *
*----------------------------------------------------------------------*
include zesi_keg_macros. "KEG Shared Macros

*----------------------------------------------------------------------*
* TABLES                                                               *
*----------------------------------------------------------------------*

*----------------------------------------------------------------------*
* TYPE POOLS                                                           *
*----------------------------------------------------------------------*
type-pools: icon.  "Zuordnung: Ikonenbezeichner in Listen zu ASCII-Codes
type-pools: abap.  "ABAP Language Type-Pool
type-pools: vrm.   "Value Request Manager: Typen und Konstanten

*----------------------------------------------------------------------*
* VARIABLES                                                            *
*----------------------------------------------------------------------*
****OK Code
data: okcode like sy-ucomm.

****Program for auth. Check
data: program type sy-repid.

*----------------------------------------------------------------------*
* INTERNAL TABLES                                                      *
*----------------------------------------------------------------------*
data: begin of exec occurs 0,
        fcode type syst-ucomm,
      end of exec.

*----------------------------------------------------------------------*
* CONSTANTS                                                            *
*----------------------------------------------------------------------*
****OK Code Contants
constants: back     like sy-ucomm value 'BACK',
           create   like sy-ucomm value 'CREATE',
           delete   like sy-ucomm value 'DELETE',
           cancel   like sy-ucomm value 'CANCEL',
           exit     like sy-ucomm value 'EXIT',
           refresh  like sy-ucomm value 'REFRESH',
           print    like sy-ucomm value 'PRINT',
           upload   like sy-ucomm value 'UPLOAD',
           stop     like sy-ucomm value 'STOP',
           close    like sy-ucomm value 'CLOSE',
           detail   like sy-ucomm value 'DETAIL',
           compare  like sy-ucomm value 'COMPARE',
           show     like sy-ucomm value 'SHOW',
           overview like sy-ucomm value 'OVERVIEW',
           yes(1)   type c        value 'J',
           no(1)    type c        value 'N'.

*----------------------------------------------------------------------*
* CLASS REFERENCES                                                     *
*----------------------------------------------------------------------*
data: abap_editor type ref to zcl_es_gui_abap_editor.
data: custom_container type ref to cl_gui_custom_container.
*----------------------------------------------------------------------*
* SELECTION-SCREEN DEFINITION                                          *
*----------------------------------------------------------------------*

*----------------------------------------------------------------------*
* START-OF-SELECTION                                                   *
*----------------------------------------------------------------------*
start-of-selection.

  perform auth_check.

****Call the main screen.
  call screen 100.

*&---------------------------------------------------------------------*
*&      Form  auth_check
*&---------------------------------------------------------------------*
*       Perform authorization check
*----------------------------------------------------------------------*
*  -->  p1        text
*  <--  p2        text
*----------------------------------------------------------------------*
form auth_check.

  move sy-repid to program.


  authority-check object 'Z_ABAP_CHK'
           id 'BUKRS' dummy
           id 'ACTVT' dummy
           id 'WERKS' dummy
           id 'REPID' field program.

  if sy-subrc ne 0.
    message e020(zes_ftp).
  endif.

endform.                    " auth_check
*&---------------------------------------------------------------------*
*&      Module  STATUS_0100  OUTPUT
*&---------------------------------------------------------------------*
*       MAIN SCREEN - PBO PROCESS BEFORE OUTPUT
*----------------------------------------------------------------------*
module status_0100 output.
  set pf-status 'MAIN'.
  set titlebar '100'.
  if custom_container is initial.
    perform create_controls.
  endif.

endmodule.                 " STATUS_0100  OUTPUT
*&---------------------------------------------------------------------*
*&      Module  USER_COMMAND_0100  INPUT
*&---------------------------------------------------------------------*
*       PAI - Screen 100 Respond to user input
*----------------------------------------------------------------------*
module user_command_0100 input.

****Case for possible user input commands
  case okcode.
    when back or
         cancel or
         exit.
      clear okcode.
      perform free_controls.
      leave to screen 0.
    when 'PRINT'.
      data: command type int4.
      command = abap_editor->cmd_print.
****Not yet working - BUG?
*      abap_editor->on_command_execute( command ).
  endcase.

endmodule.                 " USER_COMMAND_0100  INPUT
*&---------------------------------------------------------------------*
*&      Module  exit_special  INPUT
*&---------------------------------------------------------------------*
*       Exit Special - Overrides any pending activity
*----------------------------------------------------------------------*
module exit_special input.
  clear okcode.
  perform free_controls.
  leave to screen 0.
endmodule.                 " exit_special  INPUT

*&---------------------------------------------------------------------*
*&      Form  free_controls
*&---------------------------------------------------------------------*
*       Destroy all frontend controls before you exit.
*----------------------------------------------------------------------*
*  -->  p1        text
*  <--  p2        text
*----------------------------------------------------------------------*
form free_controls.

endform.                    " free_controls
*&---------------------------------------------------------------------*
*&      Form  create_controls
*&---------------------------------------------------------------------*
*       text
*----------------------------------------------------------------------*
*  -->  p1        text
*  <--  p2        text
*----------------------------------------------------------------------*
form create_controls .
  create object custom_container
    exporting
      container_name              = 'CUSTOM_CONTAINER'.

  create object abap_editor
    exporting
*    STYLE                  = 0
      parent                 = custom_container
      report_name = 'YES_ABAP_EDITOR'
*    LIFETIME               =
*    NAME                   =
*  EXCEPTIONS
*    ERROR_CNTL_CREATE      = 1
*    ERROR_CNTL_INIT        = 2
*    ERROR_CNTL_LINK        = 3
*    ERROR_DP_CREATE        = 4
*    GUI_TYPE_NOT_SUPPORTED = 5
*    others                 = 6
      .
  if sy-subrc <> 0.
* MESSAGE ID SY-MSGID TYPE SY-MSGTY NUMBER SY-MSGNO
*            WITH SY-MSGV1 SY-MSGV2 SY-MSGV3 SY-MSGV4.
  endif.

*DATA itab TYPE TABLE OF char256.
*READ REPORT 'YES_ABAP_EDITOR' INTO itab.
*CALL METHOD abap_editor->load_document
*  EXPORTING
*     TABLE    = itab
*    str_name = 'Test Program'
**  EXCEPTIONS
**    ERROR_DP = 1
**    others   = 2
*        .
*IF sy-subrc <> 0.
** MESSAGE ID SY-MSGID TYPE SY-MSGTY NUMBER SY-MSGNO
**            WITH SY-MSGV1 SY-MSGV2 SY-MSGV3 SY-MSGV4.
*ENDIF.
  cl_gui_cfw=>flush( ).
*  CALL METHOD abap_editor->add_empty_doc
*    EXPORTING
*      str_name          = 'Test Program'
*      b_readonly        = '0' "Edit Mode
*      str_extension     = 'ABAP'
*      str_tooltip       = 'Tooltip1'
**  EXCEPTIONS
**    UNABLE_TO_SET_DOC = 1
**    others            = 2
*          .
*  IF sy-subrc <> 0.
** MESSAGE ID SY-MSGID TYPE SY-MSGTY NUMBER SY-MSGNO
**            WITH SY-MSGV1 SY-MSGV2 SY-MSGV3 SY-MSGV4.
*  ENDIF.
**
**  abap_editor->set_toolbarvisible( visible = '1' ).
**  abap_editor->SET_LOCALCONTEXTMENUVIS( visible = '1' ).
*  cl_gui_cfw=>flush( ).
*



endform.                    " create_controls